@@ -1,7 +1,7 @@
 package Finance::Robinhood::Market::Hours;
 use 5.010;
 use Carp;
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -12,7 +12,7 @@ has $_ => (
     is       => 'ro',
     required => 1,
     coerce   => \&Finance::Robinhood::_2_datetime
-) for (qw[closes_at date opens_at]);
+) for (qw[closes_at extended_closes_at date opens_at extended_opens_at]);
 has $_ => (is => 'bare', required => 1, reader => "_get_$_")
     for (qw[next_open_hours previous_open_hours]);
 
@@ -71,6 +71,16 @@ returned in the form of a DateTime::Tiny object.
 The time the market closes on this particular date. This is returned in the
 form of a DateTime::Tiny object.
 
+=head2 C<extended_opens_at( )>
+
+The time the market opens for trading for this particular date for pre-open
+trading. This is returned in the form of a DateTime::Tiny object.
+
+=head2 C<extended_closes_at( )>
+
+The time the market closes on this particular date for after hours trading.
+This is returned in the form of a DateTime::Tiny object.
+
 =head2 C<next_open_hours( )>
 
 Generates a Finance::Robinhood::Market::Hours object related to the nearest
